@@ -272,6 +272,7 @@ def test_get_user(mock_connection):
             "fasGitLabUsername": [b"admin"],
             "fasWebsiteURL": [b"http://admin.example.com"],
             "fasPronoun": [b"they/them/theirs"],
+            "fasRHBZEmail": [b"admin@rhbz_example.test"],
         }
     ]
     mock_connection.result3 = _single_page_result_factory(mocked)
@@ -291,6 +292,7 @@ def test_get_user(mock_connection):
         "gitlab_username": "admin",
         "website": "http://admin.example.com",
         "pronouns": ["they/them/theirs"],
+        "rhbzemail": "admin@rhbz_example.test",
     }
     assert expected == ldap.get_user("admin")
 
@@ -440,7 +442,12 @@ def test_get_paged_search_filters(mock_connection):
     assert called_filters == [
         "(&(&(objectClass=fasUser)(!(nsAccountLock=TRUE)))(&(uid=*something*)))"
     ]
-    expected = LDAPResult(items=[], total=0, page_size=3, page_number=2,)
+    expected = LDAPResult(
+        items=[],
+        total=0,
+        page_size=3,
+        page_number=2,
+    )
     assert result == expected
 
 
@@ -499,7 +506,12 @@ def test_get_paged_search_no_results(mock_connection):
             "(givenName=*some*)(sn=*thing*)))"
         )
     ]
-    expected = LDAPResult(items=[], total=0, page_size=3, page_number=2,)
+    expected = LDAPResult(
+        items=[],
+        total=0,
+        page_size=3,
+        page_number=2,
+    )
     assert result == expected
 
 
