@@ -56,14 +56,9 @@ def test_me_service_success(client, gss_user, mock_ldap_client):
 def test_me_error(client, gss_env):
     rv = client.get("/v1/me/")
     res = rv.get_json()
-    expected = {
-        "message": (
-            "Invalid credentials (Major (851968): Unspecified GSS failure.  "
-            "Minor code may provide more information, Minor (2529639107): "
-            "No credentials cache found)"
-        )
-    }
-
     assert 403 == rv.status_code
-    # assert "Invalid credentials" == res["error"]["message"]
-    assert expected == res
+    assert "message" in res
+    assert res["message"].startswith("Invalid credentials")
+    assert res["message"].endswith(
+        "Minor (2529639107): No credentials cache found)"
+    )
