@@ -1,10 +1,13 @@
 from flask_restx import Resource
 
-from fasjson.web.utils.ipa import ldap_client
+from fasjson.web.utils import maybe_anonymize
+from fasjson.web.utils.ipa import get_attrs_from_mask, ldap_client
 from fasjson.web.utils.pagination import page_request_parser
+
 from .base import Namespace
 from .users import UserModel
 
+
 search_request_parser = page_request_parser.copy()
 search_request_parser.add_argument("email", help="The email to search for")
 search_request_parser.add_argument(
@@ -38,8 +41,12 @@ class SearchUsers(Resource):
 
         client = ldap_client()
         result = client.search_users(
-            page_size=page_size, page_number=page_number, **search_args
+            attrs=get_attrs_from_mask(UserModel),
+            page_size=page_size,
+            page_number=page_number,
+            **search_args
         )
+        result.items = [maybe_anonymize(user) for user in result.items]
         return result
 
     def _parse_page_args(self, search_args):
