@@ -1,8 +1,9 @@
-from fasjson.lib.ldap import converters, get_client
-from flask import current_app, g
-from flask_restx import abort, fields
+from flask import current_app, g, request
+from flask_restx import abort, fields, Mask
 from python_freeipa import ClientMeta
 
+from fasjson.lib.ldap import converters, get_client
+
 
 def ldap_client():
     if g.gss_creds is None or g.username is None:
@@ -31,6 +32,9 @@ def get_fields_from_ldap_model(ldap_model, endpoint, field_args=None):
     result = {}
 
     for attr, ldap_converter in ldap_model.fields.items():
+        if attr in ldap_model.hidden_fields:
+            continue
+
         if isinstance(ldap_converter, converters.BoolConverter):
             field = fields.Boolean
         elif isinstance(ldap_converter, converters.GeneralTimeConverter):
@@ -48,3 +52,11 @@ def get_fields_from_ldap_model(ldap_model, endpoint, field_args=None):
     result["uri"] = fields.Url(endpoint, absolute=True)
 
     return result
+
+
+def get_attrs_from_mask(model):
+    mask_header = current_app.config["RESTX_MASK_HEADER"]
+    mask = request.headers.get(mask_header)
+    if mask is None:
+        return None
+    return list(Mask(mask).keys())
